Overview
========

.. image:: https://secure.travis-ci.org/vmalloc/slash.png?branch=master,dev

.. image:: https://pypip.in/d/slash/badge.png

.. image:: https://pypip.in/v/slash/badge.png

Slash is a testing framework written in Python for testing complex projects. 

Fore more info, refer to the homepage at http://vmalloc.github.io/slash

Documentation
=============

Hosted at readthedocs: https://slash.readthedocs.org/en/latest/
